#import "PokktMoPubCustomBanner.h"

@implementation PokktMoPubCustomBanner
@synthesize delegate;

- (void)requestAdWithSize:(CGSize)size customEventInfo:(NSDictionary *)info
{
    NSLog(@"%@", info);
    
    screenName = [info objectForKey:@"POKKT_SCREEN_NAME"];
    appId = [info objectForKey:@"POKKT_APP_ID"];
    securityKey = [info objectForKey:@"POKKT_SEC_KEY"];
    BOOL isDebug = [[info objectForKey:@"POKKT_DEBUG"] boolValue];
    NSString *thirdPartyId = [info objectForKey:@"POKKT_THIRD_PARTY_USERID"];

    [PokktAds setPokktConfigWithAppId:appId securityKey:securityKey];
    
    // [optional] set it to true if you want to enable logs for PokktSDK
    [PokktDebugger setDebug:isDebug];
    
    [PokktAds setThirdPartyUserId:thirdPartyId];
    
    [PokktBanner setPokktBannerDelegate:self];
    
    if (self.banner_top != nil)
    {
        [self.banner_top removeFromSuperview];
        self.banner_top = nil;
    }
    
    self.banner_top = [PokktBanner initWithBannerAdSize:CGRectMake(0, 0, size.width, size.height)];
    [self.banner_top setBackgroundColor:[UIColor lightGrayColor]];
    
    UIViewController *topVC = [self topViewController];
    [topVC.view addSubview:self.banner_top];
    
    [PokktBanner loadBanner:self.banner_top withScreenName:screenName rootViewContorller:topVC];
}

- (void)bannerLoaded:(NSString *)screenName
{
    [self.delegate bannerCustomEvent:self didLoadAd:self.banner_top];
}

- (void)bannerLoadFailed:(NSString *)screenName errorMessage:(NSString *)errorMessage
{
    NSError *err = [NSError errorWithDomain:@"some_domain"
                                       code:100
                                   userInfo:@{
                                              NSLocalizedDescriptionKey:errorMessage
                                              }];
    [self.delegate bannerCustomEvent:self didFailToLoadAdWithError:err];
}


- (UIViewController*)topViewController {
    return [self topViewControllerWithRootViewController:[UIApplication sharedApplication].keyWindow.rootViewController];
}

- (UIViewController*)topViewControllerWithRootViewController:(UIViewController*)rootViewController {
    if ([rootViewController isKindOfClass:[UITabBarController class]]) {
        UITabBarController* tabBarController = (UITabBarController*)rootViewController;
        return [self topViewControllerWithRootViewController:tabBarController.selectedViewController];
    } else if ([rootViewController isKindOfClass:[UINavigationController class]]) {
        UINavigationController* navigationController = (UINavigationController*)rootViewController;
        return [self topViewControllerWithRootViewController:navigationController.visibleViewController];
    } else if (rootViewController.presentedViewController) {
        UIViewController* presentedViewController = rootViewController.presentedViewController;
        return [self topViewControllerWithRootViewController:presentedViewController];
    } else {
        return rootViewController;
    }
}


@end
