#import "PokktMoPubCustomInterstitial.h"

@implementation PokktMoPubCustomInterstitial
@synthesize delegate;

- (void)requestInterstitialWithCustomEventInfo:(NSDictionary *)info
{
    NSLog(@"%@", info);
    
    screenName = [info objectForKey:@"POKKT_SCREEN_NAME"];
    appId = [info objectForKey:@"POKKT_APP_ID"];
    securityKey = [info objectForKey:@"POKKT_SEC_KEY"];
    BOOL isDebug = [[info objectForKey:@"POKKT_DEBUG"] boolValue];
    NSString *thirdPartyId = [info objectForKey:@"POKKT_THIRD_PARTY_USERID"];
    
    [PokktAds setPokktConfigWithAppId:appId securityKey:securityKey];
    
    // [optional] set it to true if you want to enable logs for PokktSDK
    [PokktDebugger setDebug:isDebug];
    
    [PokktAds setThirdPartyUserId:thirdPartyId];
    [PokktVideoAds setPokktVideoAdsDelegate:self];
    [PokktInterstitial setPokktInterstitialDelegate:self];
    
    [PokktVideoAds cacheNonRewarded:screenName];
}

- (void)showInterstitialFromRootViewController:(UIViewController *)rootViewController
{
    if (adType == Interstitial_Ad)
    {
        [PokktInterstitial showNonRewarded:screenName withViewController:rootViewController];
    }
    else if (adType == Video_Ad)
    {
        [PokktVideoAds showNonRewarded:screenName withViewController:rootViewController];
    }
}

#pragma mark Pokkt Interstitial Ads Delegates

- (void)interstitialDisplayed: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    [self.delegate interstitialCustomEventWillAppear:self];
}


- (void)interstitialCachingCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded reward: (float)reward
{
    adType = Interstitial_Ad;
    [self.delegate interstitialCustomEvent:self didLoadAd:nil];
}

- (void)interstitialCachingFailed: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    adType = No_Ad;
    NSError *err = [NSError errorWithDomain:@"Error"
                                       code:0
                                   userInfo:@{
                                              NSLocalizedDescriptionKey:errorMessage
                                              }];
    [self.delegate interstitialCustomEvent:self didFailToLoadAdWithError:err];
}

- (void)interstitialClosed:(NSString *)screenName isRewarded: (BOOL)isRewarded
{
    adType = No_Ad;
    [self.delegate interstitialCustomEventWillDisappear:self];
}

- (void)interstitialCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    
}

- (void)interstitialSkipped: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    
}


- (void)interstitialFailedToShow: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    
}


#pragma mark Pokkt Video Ads Delegates

- (void)videoAdCachingCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded reward: (float)reward
{
    adType = Video_Ad;
     [self.delegate interstitialCustomEvent:self didLoadAd:nil];
}

- (void)videoAdCachingFailed: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    adType = No_Ad;
    [PokktInterstitial cacheNonRewarded:screenName];
}

- (void)videoAdDisplayed: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    [self.delegate interstitialCustomEventWillAppear:self];
}

- (void)videoAdClosed:(NSString *)screenName isRewarded: (BOOL)isRewarded
{
    adType = No_Ad;
    [self.delegate interstitialCustomEventWillDisappear:self];
    
}

- (void)videoAdAvailabilityStatus: (NSString *)screenName isRewarded: (BOOL)isRewarded isAdAvailable: (BOOL)isAdAvailable
{
}

- (void)videoAdFailedToShow: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    
}

- (void)videoAdCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    
}

- (void)videoAdSkipped: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    
}



@end
